### Instructions

Please go through the following checklist before submitting the PR:

- [ ] Provide an overview of the changes you're making and explain why you're proposing them.

- [ ] Include `Fixes #NNN` or `Closes #NNN` somewhere in the description if this PR addresses an existing issue.

- [ ] If this PR is not complete, select "Create Draft Pull Request" in the pull request button's menu.

  Consider using a task list (e.g., `- [ ] add tests ...`) to indicate remaining to-do items.

  The Travis tests aren't triggered for draft PRs.  If the PR is in a state where running the tests would be useful, instead submit a regular PR marked with the "WiP" label.

- [ ] If you would like to list yourself as a DataLad contributor and your name is not mentioned please modify .zenodo.json file.

- [ ] Choose a base branch for your PR's topic branch.

  The two branches that are likely candidates are `master` and the maintenance branch `0.11.x`.  Bug fixes that apply to `0.11.x` should usually go there, while everything else can go on top of `master`.

  To choose a base, (1) branch off of that point in your local repository and (2) choose the base branch in the drop-down list when creating the PR on GitHub.

- [ ] **Delete these instructions**. :-)

Thanks for contributing!
